import { formatTypeBoxErrors, validateWithTypeBox, } from '@hello.nrfcloud.com/proto';
import { HttpStatusCode } from '@hello.nrfcloud.com/proto/hello';
import { tryAsJSON } from './tryAsJSON.js';
import { aProblem } from './aProblem.js';
export const validateInput = (schema, mapInput) => {
    const v = validateWithTypeBox(schema);
    return {
        before: async (req) => {
            let reqBody = {};
            if ((req.event.headers?.['content-type'] ?? '').includes('application/json') &&
                parseInt(req.event.headers?.['content-length'] ?? '0', 10) > 0) {
                reqBody = tryAsJSON(req.event.body) ?? {};
            }
            const input = mapInput?.(req.event) ?? {
                ...(req.event.pathParameters ?? {}),
                ...(req.event.queryStringParameters ?? {}),
                ...reqBody,
            };
            console.debug(`[validateInput]`, 'input', JSON.stringify(input));
            const maybeValidInput = v(input);
            if ('errors' in maybeValidInput) {
                console.debug(`[validateInput]`, `Input not valid`, JSON.stringify(maybeValidInput.errors));
                return aProblem({
                    title: 'Validation failed',
                    status: HttpStatusCode.BAD_REQUEST,
                    detail: formatTypeBoxErrors(maybeValidInput.errors),
                });
            }
            console.debug(`[validateInput]`, `Input valid`);
            req.context.validInput = maybeValidInput.value;
            return undefined;
        },
    };
};
